@@ -1,21 +1,15 @@
 import os
 import psycopg2
+from pathlib import Path
 from psycopg2.extensions import connection
 from configparser import ConfigParser
 from dotenv import load_dotenv
-from jinja2 import PackageLoader, Environment
-
 from redscope.project.environment import REDSCOPE_CONFIG_PATH
 
 
-def get_jinja_environment() -> Environment:
-    loader = PackageLoader(package_name='redscope', package_path='templates')
-    return Environment(loader=loader, trim_blocks=True, lstrip_blocks=True)
-
-
-def get_redscope_config() -> ConfigParser:
+def get_redscope_config(config_path: Path = REDSCOPE_CONFIG_PATH) -> ConfigParser:
     config = ConfigParser()
-    config.read(REDSCOPE_CONFIG_PATH)
+    config.read(config_path)
     return config
 
 
@@ -28,11 +22,12 @@ def load_redscope_env(config: ConfigParser = None) -> None:
         load_dotenv()
 
 
-def get_redshift_connection() -> connection:
-    config = get_redscope_config()
-    var_name = config['redshift']['connection']
-    connection_string = os.getenv(var_name)
-    return psycopg2.connect(connection_string)
+def get_redshift_connection(connection_name: str = None) -> connection:
+    if connection_name:
+        return psycopg2.connect(os.getenv(connection_name))
+    else:
+        config = get_redscope_config()
+        return psycopg2.connect(os.getenv(config['redshift']['connection']))
 
 
 def init_redscope_env(provide_config: bool = False):
